#   JID.py: Implements the Jabber Identifier concept.
#   Copyright (C) 1999  Daniel Arbuckle
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#    
#   As a special exception, this code may be linked with code not covered
#   by the GNU General Public License, as long as the license covering the
#   other code does not restrict or modify the provisions governing the
#   use of this code.
#
#    Daniel Arbuckle can be contacted by email at djarb@wvc-omak.ctc.edu

import re

parse_re = re.compile(r"(?:(\w+)@)?((?:\w|\.)*)(?:/((?:\w|/)+))?")

BadJID = "Badly formatted JID"

class JID:
    """This class represents a Jabber ID (JID). It can be instantiated
    by passing it a textual JID, or by specifying the domain, node and
    resource paramaters of teh constructor seperately. Only domain is
    required. The JID can be used in most places that a string can,
    and provides access to the node, domain and resource values by
    method call."""
    def __init__(self, domain, node = "", resource = ""):
        if node or resource:
            self.__domain = domain
            self.__node = node
            self.__resource = resource
        else:
            m = parse_re.match(domain)

            if m:
                self.__node, self.__domain, self.__resource = m.groups("")
            else:
                raise BadJID, domain

    def get_domain(self):
        return self.__domain

    def get_node(self):
        return self.__node

    def get_resource(self):
        return self.__resource
    
    def __str__(self):
        if self.__node:
            ret = "%s@%s" % (self.__node, self.__domain)
        else:
            ret = self.__domain

        if self.__resource:
            ret = "%s/%s" % (ret, self.__resource)

        return ret
